
CREATE SCHEMA IF NOT EXISTS `BARRELS` ;
USE `BARRELS` ;


drop table IF EXISTS `BARRELS`.`EXIT_MOVEMENT`;
drop table IF EXISTS `BARRELS`.`ENTRY_MOVEMENT`;
drop table IF EXISTS `BARRELS`.`SUBSTANCE_COMPONENT`;
drop table IF EXISTS `BARRELS`.`MOVEMENT`;
drop table IF EXISTS `BARRELS`.`EXIT`;
drop table IF EXISTS `BARRELS`.`BATCH`;
drop table IF EXISTS `BARRELS`.`BATCH_INTERNAL`;
drop table IF EXISTS `BARRELS`.`BARREL`;
drop table IF EXISTS `BARRELS`.`SUBSTANCE`;
drop table IF EXISTS `BARRELS`.`SUBSTANCE_COMPONENT`;
drop table IF EXISTS `BARRELS`.`FAMILY`;
drop table IF EXISTS `BARRELS`.`CLIENT`;
drop table IF EXISTS `BARRELS`.`SUPPLIER`;
drop table IF EXISTS `BARRELS`.`SAMPLE`;
drop table IF EXISTS `BARRELS`.`MINIMUM_AMOUNT_ANALITIC`;
drop table IF EXISTS `BARRELS`.`LOTE_SEQUENCE`;
drop table IF EXISTS `BARRELS`.`ANALYSIS_PARAMETER`;
drop table IF EXISTS `BARRELS`.`EXTERNAL_SAMPLE`;
drop table IF EXISTS `BARRELS`.`SUPPLIER`;
drop table IF EXISTS `BARRELS`.`BATCH_SEQUENCE`;
drop table IF EXISTS `BARRELS`.`LINE_RESERVE_SAMPLE`;
drop table IF EXISTS `BARRELS`.`COMPONENT`;
drop table IF EXISTS `BARRELS`.`COMPONENT_SYNONIMOUS`;
DROP TABLE IF EXISTS `BARRELS`.`PAYMENT`;
DROP TABLE IF EXISTS `BARRELS`.`RECEIPT_LINE_SAMPLE`;
DROP TABLE IF EXISTS `BARRELS`.`RECEIPT_LINE_EXIT`;
DROP TABLE IF EXISTS `BARRELS`.`RECEIPT_LINE`;
DROP TABLE IF EXISTS `BARRELS`.`RECEIPT`;
DROP TABLE IF EXISTS `BARRELS`.`COMPONENT_VALUE`;
DROP TABLE IF EXISTS `BARRELS`.`ANALITIC_SIMPLE`;

-- -----------------------------------------------------
-- Table `BARRELS`.`SUPPLIER`
-- -----------------------------------------------------
CREATE  TABLE IF NOT EXISTS `BARRELS`.`SUPPLIER` (
  `CODE` INT NOT NULL AUTO_INCREMENT,
  `NAME` VARCHAR(45) NOT NULL ,
  PRIMARY KEY (`CODE`) ,
  UNIQUE INDEX `NAME_UNIQUE1` (`NAME` ASC) )
;



-- -----------------------------------------------------
-- Table `BARRELS`.`CLIENT`
-- -----------------------------------------------------
CREATE  TABLE IF NOT EXISTS `BARRELS`.`CLIENT` (
  `CODE` INT NOT NULL AUTO_INCREMENT,
  `NAME` VARCHAR(45) NULL ,
  `ADDRESS` VARCHAR(145) NULL ,
  `PHONE` VARCHAR(14) NULL ,
  `COUNTRY` VARCHAR(50) NULL ,
  `TOWN` VARCHAR(50) NULL ,
  PRIMARY KEY (`CODE`) ,
UNIQUE INDEX ` NAME_CLIENT_UNIQUE` (`NAME` ASC) )
;



-- -----------------------------------------------------
-- Table `BARRELS`.`FAMILY`
-- -----------------------------------------------------
CREATE  TABLE IF NOT EXISTS `BARRELS`.`FAMILY` (
  `CODE` INT NOT NULL AUTO_INCREMENT,
  `NAME` VARCHAR(45) NULL ,
`ISCOMPONENT` BIT(1) NOT NULL DEFAULT 1,
  PRIMARY KEY (`CODE`) ,
  UNIQUE INDEX `NAME_UNIQUE2` (`NAME` ASC) )
;



-- -----------------------------------------------------
-- Table `BARRELS`.`SUSTANCIA`
-- -----------------------------------------------------
CREATE  TABLE IF NOT EXISTS `BARRELS`.`SUBSTANCE` (
  `CODE` INT NOT NULL AUTO_INCREMENT,
  `DESCRIPTION` VARCHAR(45) NOT NULL ,
  `FAMILY_CODE` INT NULL ,
  `NAME_LATIN` VARCHAR(45) NULL ,
  `SECOND_LANGUAGE_NAME` VARCHAR(45) NULL ,
  `MINIMUM_AMOUNT` FLOAT NULL ,
  `PRICE` FLOAT,
UNIQUE INDEX ` SUS_DESCRI_UNIQUE` (`DESCRIPTION` ASC) ,
  PRIMARY KEY (`CODE`) ,
  CONSTRAINT `fk_SUBSTANCE_FAMILY1`
    FOREIGN KEY (`FAMILY_CODE` )
    REFERENCES `BARRELS`.`FAMILY` (`CODE` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION)
;


-- -----------------------------------------------------
-- Table `BARRELS`.`PEDIDO`
-- -----------------------------------------------------
CREATE  TABLE IF NOT EXISTS `BARRELS`.`CUSTOMER_ORDER` (
  `CODE` INT NOT NULL AUTO_INCREMENT,
  `SUBSTANCE_CODE` INT NOT NULL ,
  `AMOUNT` FLOAT NULL ,
  `CLIENT_CODE` INT NOT NULL ,
  PRIMARY KEY (`CODE`) ,
  CONSTRAINT `fk_ORDER_SUBSTANCE_copy21`
    FOREIGN KEY (`SUBSTANCE_CODE` )
    REFERENCES `BARRELS`.`SUBSTANCE` (`CODE` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION,
  CONSTRAINT `fk_ORDER_CLIENT1`
    FOREIGN KEY (`CLIENT_CODE` )
    REFERENCES `BARRELS`.`CLIENT` (`CODE` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION)
;


-- -----------------------------------------------------
-- Table `BARRELS`.`BIDON`
-- -----------------------------------------------------
CREATE  TABLE IF NOT EXISTS `BARRELS`.`BARREL` (
  `CODE` VARCHAR(10) NOT NULL ,
  `SUBSTANCE_CODE` INT NOT NULL ,
  PRIMARY KEY (`CODE`) ,
  CONSTRAINT `fk_BARREL_SUBSTANCE1`
    FOREIGN KEY (`SUBSTANCE_CODE` )
    REFERENCES `BARRELS`.`SUBSTANCE` (`CODE` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION)
;



-- -----------------------------------------------------
-- Table `BARRELS`.`LOTE`
-- -----------------------------------------------------
CREATE  TABLE IF NOT EXISTS `BARRELS`.`BATCH` (
  `CODE` VARCHAR(50) NOT NULL ,
  PRIMARY KEY (`CODE`) )
;




-- -----------------------------------------------------
-- Table `BARRELS`.`MUESTRA`
-- -----------------------------------------------------
CREATE  TABLE IF NOT EXISTS `BARRELS`.`SAMPLE` (
  `CODE` INT NOT NULL AUTO_INCREMENT,
  `STATUS` VARCHAR(4) NULL ,
  `ORDER_CODE` INT NOT NULL ,
  `CERTIFICATION` VARCHAR(3) NULL ,
  `SENT_DATE` DATE NULL ,
  `VIRTUAL` BIT(1) NOT NULL ,
  `BATCH_CODE` VARCHAR(50) NULL ,
  `NOTE` VARCHAR(100),
  PRIMARY KEY (`CODE`) ,
  CONSTRAINT `fk_SAMPLE_ORDER1`
    FOREIGN KEY (`ORDER_CODE` )
    REFERENCES `BARRELS`.`CUSTOMER_ORDER` (`CODE` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION,
  CONSTRAINT `fk_SAMPLE_BATCH1`
    FOREIGN KEY (`BATCH_CODE` )
    REFERENCES `BARRELS`.`BATCH` (`CODE` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION)
;


-- -----------------------------------------------------
-- Table `BARRELS`.`ASIENTO`
-- -----------------------------------------------------
CREATE  TABLE IF NOT EXISTS `BARRELS`.`EXIT` (
  `CODE` INT NOT NULL AUTO_INCREMENT,
  `NOTE` VARCHAR(200) NULL ,
  `DESIRED_AMOUNT` FLOAT NULL ,
  `STATUS` INT(2) NULL ,
  `DATE` DATETIME NOT NULL ,
  `TARGET_BARREL` VARCHAR(10) NULL ,
  `CLIENT_CODE` INT NULL ,
  `SAMPLE_CODE` INT NULL ,
  `SUBSTANCE_CODE` INT NOT NULL ,
  `BATCH_CODE` VARCHAR(50) NOT NULL ,
  `RESERVED_AMOUNT` FLOAT NULL,
  `CERTIFICACION` VARCHAR(3) NULL,
  CERTIFICATION VARCHAR(3) NULL,
  PRIMARY KEY (`CODE`) ,
  CONSTRAINT `fk_EXIT_BARREL1`
    FOREIGN KEY (`TARGET_BARREL` )
    REFERENCES `BARRELS`.`BARREL` (`CODE` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION,
  CONSTRAINT `fk_EXIT_CLIENT1`
    FOREIGN KEY (`CLIENT_CODE` )
    REFERENCES `BARRELS`.`CLIENT` (`CODE` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION,
  CONSTRAINT `fk_EXIT_SUBSTANCE1`
    FOREIGN KEY (`SUBSTANCE_CODE` )
    REFERENCES `BARRELS`.`SUBSTANCE` (`CODE` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION,
  CONSTRAINT `fk_EXIT_BATCH1`
    FOREIGN KEY (`BATCH_CODE` )
    REFERENCES `BARRELS`.`BATCH` (`CODE` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION,
  CONSTRAINT `fk_EXIT_SAMPLE1`
    FOREIGN KEY (`SAMPLE_CODE` )
    REFERENCES `BARRELS`.`SAMPLE` (`CODE` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION
    
   )
;



-- -----------------------------------------------------
-- Table `BARRELS`.`MOVEMENT`
-- -----------------------------------------------------
CREATE  TABLE IF NOT EXISTS `BARRELS`.`MOVEMENT` (
  `CODE` INT NOT NULL AUTO_INCREMENT,
  `AFFECTED_BARREL` VARCHAR(10) NOT NULL ,
  `DATE` DATETIME NULL ,
  `KILOS` FLOAT NULL ,
  `NOTES` VARCHAR(45) NULL ,
  `RESET` BINARY NOT NULL ,
  `TYPE` VARCHAR(2) NOT NULL ,
  PRIMARY KEY (`CODE`) ,
CERTIFICATION VARCHAR(3) NULL,
  CONSTRAINT `fk_MOVEMENT_BARREL1`
    FOREIGN KEY (`AFFECTED_BARREL` )
    REFERENCES `BARRELS`.`BARREL` (`CODE` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION)
;




-- -----------------------------------------------------
-- Table `BARRELS`.`ENTRY_MOVEMENT`
-- -----------------------------------------------------
CREATE  TABLE IF NOT EXISTS `BARRELS`.`ENTRY_MOVEMENT` (
  `MOVEMENT_CODE` INT NOT NULL ,
  `BARREL_SOURCE` VARCHAR(10) NULL ,
  `SUPPLIER_CODE` INT NULL ,
  `SUBSTANCE_CODE` INT NOT NULL ,
PRICE FLOAT,
  PRIMARY KEY (`MOVEMENT_CODE`) ,
  CONSTRAINT `fk_ENTRY_MOVEMENT_MOVEMENT1`
    FOREIGN KEY (`MOVEMENT_CODE` )
    REFERENCES `BARRELS`.`MOVEMENT` (`CODE` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION,
  CONSTRAINT `fk_ENTRY_MOVEMENT_BARREL1`
    FOREIGN KEY (`BARREL_SOURCE` )
    REFERENCES `BARRELS`.`BARREL` (`CODE` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION,
  CONSTRAINT `fk_ENTRY_MOVEMENT_SUPPLIER1`
    FOREIGN KEY (`SUPPLIER_CODE` )
    REFERENCES `BARRELS`.`SUPPLIER` (`CODE` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION,
  CONSTRAINT `fk_ENTRY_MOVEMENT_SUBSTANCE`
    FOREIGN KEY (`SUBSTANCE_CODE` )
    REFERENCES `BARRELS`.`SUBSTANCE` (`CODE` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION)
;



-- -----------------------------------------------------
-- Table `BARRELS`.`EXIT_MOVEMENT`
-- -----------------------------------------------------
CREATE  TABLE IF NOT EXISTS `BARRELS`.`EXIT_MOVEMENT` (
  `MOVEMENT_CODE` INT NOT NULL ,
  `EXIT_CODE` INT NOT NULL ,
  PRIMARY KEY (`MOVEMENT_CODE`) ,
  CONSTRAINT `fk_EXIT_MOVEMENT_MOVEMENT1`
    FOREIGN KEY (`MOVEMENT_CODE` )
    REFERENCES `BARRELS`.`MOVEMENT` (`CODE` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION,
  CONSTRAINT `fk_EXIT_MOVEMENT_EXIT1`
    FOREIGN KEY (`EXIT_CODE` )
    REFERENCES `BARRELS`.`EXIT` (`CODE` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION)
;



-- -----------------------------------------------------
-- Table `BARRELS`.`EXTERNAL_SAMPLE`
-- -----------------------------------------------------
CREATE  TABLE IF NOT EXISTS `BARRELS`.`EXTERNAL_SAMPLE` (
  `CODE` INT NOT NULL AUTO_INCREMENT,
  `SUPPLIER_CODE` INT NOT NULL ,
  `SUBSTANCE_CODE` INT NOT NULL ,
  `KILOS` FLOAT NULL ,
  `DATE` DATE NULL ,
  `IDENTIFIER` VARCHAR(45) NULL ,
`NOTES`VARCHAR(100) NULL ,
  PRIMARY KEY (`CODE`) ,
  CONSTRAINT `fk_EXTERNAL_SAMPLE_SUPPLIER1`
    FOREIGN KEY (`SUPPLIER_CODE` )
    REFERENCES `BARRELS`.`SUPPLIER` (`CODE` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION,
  CONSTRAINT `fk_EXTERNAL_SAMPLE_SUBSTANCE_copy11`
    FOREIGN KEY (`SUBSTANCE_CODE` )
    REFERENCES `BARRELS`.`SUBSTANCE` (`CODE` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION)
;






-- -----------------------------------------------------
-- Table `BARRELS`.`BATCH_INTERNAL`
-- -----------------------------------------------------
CREATE  TABLE IF NOT EXISTS `BARRELS`.`BATCH_INTERNAL` (
  `BATCH_CODE` VARCHAR(50) NOT NULL ,
  `BARREL_CODE` VARCHAR(10) NOT NULL ,
  `DATE` DATE NOT NULL ,
  `NOTE` VARCHAR(45) NULL ,
  EXTERNAL_SAMPLE_CODE int(11),
  BATCH_REFERENCE VARCHAR(45),
CERTIFICATION VARCHAR(3) NULL,
  PRIMARY KEY (`BATCH_CODE`) ,
  CONSTRAINT `fk_BATCH_INTERNAL_BATCH1`
    FOREIGN KEY (`BATCH_CODE` )
    REFERENCES `BARRELS`.`BATCH` (`CODE` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION,
  CONSTRAINT `fk_BATCH_INTERNAL_BARREL1`
    FOREIGN KEY (`BARREL_CODE` )
    REFERENCES `BARRELS`.`BARREL` (`CODE` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION,
   CONSTRAINT FK_BATCHIN_EXTERNAL_SAMPLE FOREIGN KEY (`EXTERNAL_SAMPLE_CODE`) REFERENCES `BARRELS`.`EXTERNAL_SAMPLE`(`CODE`)
    );





CREATE TABLE IF NOT EXISTS BATCH_SEQUENCE(
`CODE` INT AUTO_INCREMENT,
PRIMARY KEY (`CODE`) 
);










-- -----------------------------------------------------
-- Table `BARRELS`.`LINEA_RESERVA_MUESTRA`
-- -----------------------------------------------------
CREATE  TABLE IF NOT EXISTS `BARRELS`.`LINE_RESERVE_SAMPLE` (
  `CODE` INT NOT NULL AUTO_INCREMENT,
  `SAMPLE_CODE` INT NOT NULL ,
  `EXTERNAL_SAMPLE_CODE` INT NULL ,
  `BARREL_CODE` VARCHAR(10) NULL ,
  `PERCENTAGE` FLOAT NULL ,
  `RESERVED_PART` FLOAT NULL ,
  `ASSOCIATED_BATCH` VARCHAR(50) NULL ,
  PRIMARY KEY (`CODE`, `SAMPLE_CODE`) ,
  CONSTRAINT `fk_LINEA_RESERVA_EXTERNAL_SAMPLEL_SAMPLE1`
    FOREIGN KEY (`EXTERNAL_SAMPLE_CODE` )
    REFERENCES `BARRELS`.`EXTERNAL_SAMPLE` (`CODE` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION,
  CONSTRAINT `fk_LINE_RESERVE_SAMPLE_BARREL_copy11`
    FOREIGN KEY (`BARREL_CODE` )
    REFERENCES `BARRELS`.`BARREL` (`CODE` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION,
  CONSTRAINT `fk_LINE_RESERVE_SAMPLE_BATCH_copy11`
    FOREIGN KEY (`ASSOCIATED_BATCH` )
    REFERENCES `BARRELS`.`BATCH` (`CODE` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION,
  CONSTRAINT `fk_LINE_RESERVE_SAMPLE_SAMPLE1`
    FOREIGN KEY (`SAMPLE_CODE` )
    REFERENCES `BARRELS`.`SAMPLE` (`CODE` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION)
;





-- -----------------------------------------------------
-- Table `BARRELS`.`COMPONENTE`
-- -----------------------------------------------------
CREATE  TABLE IF NOT EXISTS `BARRELS`.`COMPONENT` (
  `CODE` INT NOT NULL AUTO_INCREMENT,
  `DESCRIPTION` VARCHAR(145) NULL ,
  `CAS_NUMBER` VARCHAR(45) NULL ,
  `INCHI_KEY` VARCHAR(45) NULL ,
  `EC_NUMBER` VARCHAR(45) NULL ,
  `ALLERGEN` BIT(1) NOT NULL DEFAULT 0,
  UNIQUE INDEX `DESCRIPTION_COMPONENT_UNIQUE` (`DESCRIPTION` ASC),
  UNIQUE INDEX `CAS_NUMBER_UNIQUE` (`CAS_NUMBER` ASC),
  UNIQUE INDEX `INCHI_KEY_UNIQUE` (`INCHI_KEY` ASC),
  UNIQUE INDEX `NC_NUMBER_UNIQUE` (`EC_NUMBER` ASC),
  PRIMARY KEY (`CODE`) )
;



-- -----------------------------------------------------
-- Table `BARRELS`.`SUSTANCIA_COMPONENTE`
-- -----------------------------------------------------
CREATE  TABLE IF NOT EXISTS `BARRELS`.`SUBSTANCE_COMPONENT` (
  `SUBSTANCE_CODE` INT NOT NULL ,
  `COMPONENT_CODE` INT NOT NULL ,
  PRIMARY KEY (`SUBSTANCE_CODE`, `COMPONENT_CODE`) ,
  CONSTRAINT `fk_SUBSTANCE_has_COMPONENT_SUBSTANCE1`
    FOREIGN KEY (`SUBSTANCE_CODE` )
    REFERENCES `BARRELS`.`SUBSTANCE` (`CODE` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION,
  CONSTRAINT `fk_SUBSTANCE_has_COMPONENT_COMPONENT1`
    FOREIGN KEY (`COMPONENT_CODE` )
    REFERENCES `BARRELS`.`COMPONENT` (`CODE` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION)
;



-- -----------------------------------------------------
-- Table `BARRELS`.`ANALITICA_SIMPLE`
-- -----------------------------------------------------
CREATE  TABLE IF NOT EXISTS `BARRELS`.`ANALITIC_SIMPLE` (
  `CODE` INT NOT NULL AUTO_INCREMENT,
  `SUBSTANCE_CODE` INT NOT NULL ,
  `BATCH` VARCHAR(50) NULL ,
  `EXTERNAL_SAMPLE` INT NULL ,
  `NOTE` VARCHAR(50) NULL ,
  `DATE` DATE NULL ,
`DENSITY` FLOAT NULL ,
`REFRACTION` FLOAT NULL ,
`ROTATION` FLOAT NULL ,
  PRIMARY KEY (`CODE`) ,
  CONSTRAINT `fk_ANALITIC_SIMPLE_SUBSTANCE_copy21`
    FOREIGN KEY (`SUBSTANCE_CODE` )
    REFERENCES `BARRELS`.`SUBSTANCE` (`CODE` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION,
  CONSTRAINT `fk_ANALITIC_SIMPLE_BATCH`
    FOREIGN KEY (`BATCH` )
    REFERENCES `BARRELS`.`BATCH` (`CODE` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION,
  CONSTRAINT `fk_ANALITIC_SIMPLE_EXTERNAL_SAMPLE_copy11`
    FOREIGN KEY (`EXTERNAL_SAMPLE` )
    REFERENCES `BARRELS`.`EXTERNAL_SAMPLE` (`CODE` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION)
;


-- -----------------------------------------------------
-- Table `BARRELS`.`VALOR_COMPONENTE`
-- -----------------------------------------------------
CREATE  TABLE IF NOT EXISTS `BARRELS`.`COMPONENT_VALUE` (
  `CODE` INT NOT NULL AUTO_INCREMENT,
  `COMPONENT_CODE` INT NOT NULL ,
  `ANALITIC_SIMPLE_CODE` INT NOT NULL ,
  `VALUE` FLOAT NULL ,
  PRIMARY KEY (`CODE`) ,
UNIQUE INDEX `COMPONENT_ANALITIC_UNIQUE` (`COMPONENT_CODE`,`ANALITIC_SIMPLE_CODE` ASC),
  CONSTRAINT `fk_COMPONENT_VALUE_COMPONENT1`
    FOREIGN KEY (`COMPONENT_CODE` )
    REFERENCES `BARRELS`.`COMPONENT` (`CODE` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION,
  CONSTRAINT `fk_COMPONENT_VALUE_ANALITIC_SIMPLE1`
    FOREIGN KEY (`ANALITIC_SIMPLE_CODE` )
    REFERENCES `BARRELS`.`ANALITIC_SIMPLE` (`CODE` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION)
;


-- -----------------------------------------------------
-- Table `BARRELS`.`ANALITICA_COMPUESTA`
-- -----------------------------------------------------
CREATE  TABLE IF NOT EXISTS `BARRELS`.`ANALITIC_COMPOUND` (
  `ANALITIC_SIMPLE_CODE` INT NOT NULL ,
 `NOTE` VARCHAR(45) NULL ,
  PRIMARY KEY (`ANALITIC_SIMPLE_CODE`) ,
    FOREIGN KEY (`ANALITIC_SIMPLE_CODE` )
    REFERENCES `BARRELS`.`ANALITIC_SIMPLE` (`CODE` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION)
;



-- -----------------------------------------------------
-- Table `BARRELS`.`ANALITICA_PONDERACION`
-- -----------------------------------------------------
CREATE  TABLE IF NOT EXISTS `BARRELS`.`ANALITIC_PONDERATION` (
  `CODE` INT NOT NULL AUTO_INCREMENT,
  `ANALITIC_COMPOUND_ID` INT NOT NULL ,
  `ANALITIC_SIMPLE` INT NOT NULL ,
  `PONDERATION` FLOAT NULL ,
  PRIMARY KEY (`CODE`) ,
  CONSTRAINT `fk_ANALITIC_PONDERATION_ANALITIC_COMPOUND1`
    FOREIGN KEY (`ANALITIC_COMPOUND_ID` )
    REFERENCES `BARRELS`.`ANALITIC_COMPOUND` (`ANALITIC_SIMPLE_CODE` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION,
  CONSTRAINT `fk_ANALITIC_PONDERATION_ANALITIC_SIMPLE1`
    FOREIGN KEY (`ANALITIC_SIMPLE` )
    REFERENCES `BARRELS`.`ANALITIC_SIMPLE` (`CODE` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION)
;



-- -----------------------------------------------------
-- Table `BARRELS`.`ISO`
-- -----------------------------------------------------
CREATE  TABLE IF NOT EXISTS `BARRELS`.`ISO` (
  `CODE` INT NOT NULL AUTO_INCREMENT,
  `DESCRIPTION` VARCHAR(45) NULL ,
  `SUBSTANCE_CODE` INT NOT NULL ,
  PRIMARY KEY (`CODE`) ,
  CONSTRAINT `fk_ISO_SUBSTANCE_copy21`
    FOREIGN KEY (`SUBSTANCE_CODE` )
    REFERENCES `BARRELS`.`SUBSTANCE` (`CODE` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION)
;



-- -----------------------------------------------------
-- Table `BARRELS`.`RANGO_COMPONENTE_ISO`
-- -----------------------------------------------------
CREATE  TABLE IF NOT EXISTS `BARRELS`.`RANGE_COMPONENT_ISO` (
  `CODE` INT NOT NULL AUTO_INCREMENT,
  `ISO_CODE` INT NOT NULL ,
  `MINIMUM_VALUE` FLOAT NULL ,
  `MAXIMUM_VALUE` FLOAT NULL ,
  `COMPONENT_CODE` INT NOT NULL ,
  PRIMARY KEY (`CODE`) ,
  CONSTRAINT `fk_RANGE_COMPONENT_ISO_ISO1`
    FOREIGN KEY (`ISO_CODE` )
    REFERENCES `BARRELS`.`ISO` (`CODE` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION,
  CONSTRAINT `fk_RANGE_COMPONENT_ISO_COMPONENT1`
    FOREIGN KEY (`COMPONENT_CODE` )
    REFERENCES `BARRELS`.`COMPONENT` (`CODE` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION)
;




-- -----------------------------------------------------
-- Table `BARRELS`.`CONFIGURACION_VENTANA`
-- -----------------------------------------------------
CREATE  TABLE IF NOT EXISTS `BARRELS`.`WINDOW_CONFIGURATION` (
  `CODE` INT NOT NULL AUTO_INCREMENT,
  `SUBSTANCE_CODE` INT NOT NULL ,
  PRIMARY KEY (`CODE`) ,
  CONSTRAINT `fk_WINDOW_CONFIGURATION_SUBSTANCE_copy21`
    FOREIGN KEY (`SUBSTANCE_CODE` )
    REFERENCES `BARRELS`.`SUBSTANCE` (`CODE` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION)
;



-- -----------------------------------------------------
-- Table `BARRELS`.`CONFIGURACION_VENTANA_COMPONENTE`
-- -----------------------------------------------------
CREATE  TABLE IF NOT EXISTS `BARRELS`.`WINDOW_COMPONENT_CONFIGURATION` (
  `COMPONENT_CODE` INT NOT NULL ,
  `ANALITIC_CONFIGURATION` INT NOT NULL ,
`DORDER` INT(3)  ,
  PRIMARY KEY (`COMPONENT_CODE`, `ANALITIC_CONFIGURATION`) ,
  CONSTRAINT `fk_COMPONENT_copy1_has_CONFIGURATION_ANALITIC_COMPOUND_ESEN1`
    FOREIGN KEY (`COMPONENT_CODE` )
    REFERENCES `BARRELS`.`COMPONENT` (`CODE` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION,
  CONSTRAINT `fk_COMPONENT_copy1_has_CONFIGURATION_ANALITIC_COMPOUND_ESEN2`
    FOREIGN KEY (`ANALITIC_CONFIGURATION` )
    REFERENCES `BARRELS`.`WINDOW_CONFIGURATION` (`CODE` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION)
;


-- -----------------------------------------------------
-- Table `BARRELS`.`CONFIGURACION_VENTANA_ANALITICA`
-- -----------------------------------------------------
CREATE  TABLE IF NOT EXISTS `BARRELS`.`WINDOW_ANALITIC_CONFIGURATION` (
  `WINDOW_CONFIGURATION_CODE` INT NOT NULL ,
  `ANALITIC_SIMPLE_CODE` INT NOT NULL ,
`DORDER` INT(3)  ,
  PRIMARY KEY (`WINDOW_CONFIGURATION_CODE`, `ANALITIC_SIMPLE_CODE`) ,
  CONSTRAINT `fk_WINDOW_CONFIGURATION_has_ANALITIC_SIMPLE_CONFIGURATION_V1`
    FOREIGN KEY (`WINDOW_CONFIGURATION_CODE` )
    REFERENCES `BARRELS`.`WINDOW_CONFIGURATION` (`CODE` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION,
  CONSTRAINT `fk_WINDOW_CONFIGURATION_has_ANALITIC_SIMPLE_ANALITIC_SIMPLE1`
    FOREIGN KEY (`ANALITIC_SIMPLE_CODE` )
    REFERENCES `BARRELS`.`ANALITIC_SIMPLE` (`CODE` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION)
;


-- -----------------------------------------------------
-- Table `BARRELS`.`CONFIGURACION_VENTANA_ISO`
-- -----------------------------------------------------
CREATE  TABLE IF NOT EXISTS `BARRELS`.`WINDOW_ISO_CONFIGURATION` (
  `ISO_CODE` INT NOT NULL ,
  `WINDOW_CONFIGURATION` INT NOT NULL ,
  PRIMARY KEY (`ISO_CODE`, `WINDOW_CONFIGURATION`) ,
  CONSTRAINT `fk_ISO_copy1_has_WINDOW_ISO_CONFIGURATION_copy11`
    FOREIGN KEY (`ISO_CODE` )
    REFERENCES `BARRELS`.`ISO` (`CODE` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION,
  CONSTRAINT `fk_ISO_copy1_has_WINDOW_CONFIGURATION_WINDOW_CONFIGURATION1`
    FOREIGN KEY (`WINDOW_CONFIGURATION` )
    REFERENCES `BARRELS`.`WINDOW_CONFIGURATION` (`CODE` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION)
;



CREATE  TABLE IF NOT EXISTS `BARRELS`.`RANGE_COMPONENT_ISO` (
  `CODE` INT NOT NULL ,
  `ISO_CODE` INT NOT NULL ,
  `MINIMUM_VALUE` FLOAT NULL ,
  `MAXIMUM_VALUE` FLOAT NULL ,
  `COMPONENT_CODE` INT NOT NULL ,
  PRIMARY KEY (`CODE`, `ISO_CODE`) ,
  CONSTRAINT `fk_RANGE_COMPONENT_ISO_ISO1`
    FOREIGN KEY (`ISO_CODE` )
    REFERENCES `BARRELS`.`ISO` (`CODE` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION,
  CONSTRAINT `fk_RANGE_COMPONENT_ISO_COMPONENT1`
    FOREIGN KEY (`COMPONENT_CODE` )
    REFERENCES `BARRELS`.`COMPONENT` (`CODE` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION)
;



CREATE  TABLE IF NOT EXISTS `BARRELS`.`MINIMUM_AMOUNT_ANALITIC` (
`CODE` INT NOT NULL ,
  `VALUE` FLOAT NOT NULL ,
  PRIMARY KEY (`CODE`) )
;

-- ----------------------------------------------------------------

-- CANTIDAD_PREPRACION_MUESTRA

-- ----------------------------------------------------------------


CREATE  TABLE IF NOT EXISTS `BARRELS`.`AMOUNT_PREPARATION_SAMPLE` (
  `CODE` INT NOT NULL AUTO_INCREMENT,
  `SAMPLE_CODE` INT(11) NOT NULL ,
  `AMOUNT` FLOAT NOT NULL,
  PRIMARY KEY (`CODE`) ,
  CONSTRAINT `fk_AMOUNT_PREPARATION_SAMPLE1`
    FOREIGN KEY (`SAMPLE_CODE` )
    REFERENCES `BARRELS`.`SAMPLE` (`CODE` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION)
;


-- -----------------------------------------------------
-- Table `BARRELS`.`ESSENCE_ALREADY_ORDERED`
-- -----------------------------------------------------
-- --DEPRECATED

drop table IF EXISTS `BARRELS`.`ESSENCE_ALREADY_ORDERED`;

CREATE  TABLE IF NOT EXISTS `BARRELS`.`ESSENCE_ALREADY_ORDERED` (
  `CODE` INT(11) ,
  `DATE` DATETIME NULL ,
  `NOTES` VARCHAR(100) NULL,
  PRIMARY KEY (`CODE`) ,
  UNIQUE INDEX `CODE_ALREADY_ESSENCE_UNIQUE` (`CODE` ASC) ,
CONSTRAINT `fk_ESSENCE_ALREADY_ESSENCE`
    FOREIGN KEY (`CODE` )
    REFERENCES `BARRELS`.`SUBSTANCE` (`CODE` ))
;

-- -----------------------------------------------------
-- Table `BARRELS`.`COMPONENT_SYNONIMOUS`
-- -----------------------------------------------------
CREATE  TABLE IF NOT EXISTS `BARRELS`.`COMPONENT_SYNONIMOUS` (
  `CODE` INT(11) AUTO_INCREMENT,
  `CODE_COMPONENT` INT(11),
  `NAME` VARCHAR(145),
  PRIMARY KEY (`CODE`) ,
  UNIQUE INDEX `CODE_ALREADY_COMPONENT_UNIQUE` (`CODE` ASC) ,
  UNIQUE INDEX `NAME_COMPONENT_UNIQUE` (`NAME` ASC) ,
CONSTRAINT `fk_CODE_SUBSTANCE`
    FOREIGN KEY (`CODE_COMPONENT` )
    REFERENCES `BARRELS`.`COMPONENT` (`CODE` ))
;


CREATE  TABLE IF NOT EXISTS `BARRELS`.`ANALYSIS_PARAMETER` (
  `CODE` INT NOT NULL AUTO_INCREMENT,
  `NAME` VARCHAR(45) NOT NULL ,
  `NAME_SECOND_LANGUAGE` VARCHAR(45) NOT NULL ,
  `TYPE_PARAMETER` VARCHAR(45) NULL,
  `UNITS` VARCHAR(45) NULL,
  `SHOW_IN_CALCULATION` BIT(1) NOT NULL DEFAULT 0,
  `SHOW_IN_REPORT` BIT(1)  NOT NULL DEFAULT 0,
  UNIQUE INDEX `NAME_UNIQUE3` (`NAME` ASC) ,
  PRIMARY KEY (`CODE`) )
;

CREATE TABLE IF NOT EXISTS `BARRELS`.`ANALYTIC_VALUE_PARAMETER` (
  `CODE` INT NOT NULL AUTO_INCREMENT,
  `CODE_ANALYTIC` INT NOT NULL,
  `CODE_PARAMETER` INT NOT NULL,
  `VALUE` FLOAT NULL,
UNIQUE INDEX `ANALYTIC_VALUE_PARAMETER_UNIQUE` (`CODE_ANALYTIC`,`CODE_PARAMETER` ASC),
CONSTRAINT `fk_CODE_ANALYTIC_VALUE_ANALYSIS`
    FOREIGN KEY (`CODE_ANALYTIC` )
    REFERENCES `BARRELS`.`ANALITIC_SIMPLE` (`CODE` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION,
CONSTRAINT `fk_CODE_PARAMETER_ANALYSIS`
    FOREIGN KEY (`CODE_PARAMETER` )
    REFERENCES `BARRELS`.`ANALYSIS_PARAMETER` (`CODE` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION,
  PRIMARY KEY (`CODE`) 
)
;

CREATE  TABLE IF NOT EXISTS `BARRELS`.`TEXT_ANALYTIC` (
`CODE` INT NOT NULL AUTO_INCREMENT,
`TITLE` VARCHAR(45) NULL ,
`TEXT` VARCHAR(1000) NULL ,
DEFAULT_IN_REPORT BIT(1) NOT NULL DEFAULT 0,
  PRIMARY KEY (`CODE`) )
;





-- -----------------------------------------------------
-- Table `BARRELS`.`SUBSTANCE_SYNONIMOUS`
-- -----------------------------------------------------
CREATE  TABLE IF NOT EXISTS `BARRELS`.`SUBSTANCE_SYNONIMOUS` (
  `CODE` INT(11) AUTO_INCREMENT,
  `SUSTANCIA_CODIGO` INT(11) ,
  `NAME` VARCHAR(145),
  `NAME_SECOND_LANGUAGE` VARCHAR(145),
  `LATIN_NAME` VARCHAR(145),
  `STANDARD` VARCHAR(45),
  PRIMARY KEY (`CODE`) ,
  UNIQUE INDEX `CODE_ALREADY_SUB_SYNO` (`CODE` ASC) ,
CONSTRAINT `fk_SUBSY_SUBSTANCE`
    FOREIGN KEY (`SUSTANCIA_CODIGO` )
    REFERENCES `BARRELS`.`SUBSTANCE` (`CODE` ))
;


-- -----------------------------------------------------
-- Table `BARRELS`.`RANGE_ANALPARAM_ISO`
-- -----------------------------------------------------
CREATE  TABLE IF NOT EXISTS `BARRELS`.`RANGE_ANALPARAM_ISO` (
  `CODE` INT NOT NULL AUTO_INCREMENT,
  `ISO_CODIGO` INT NOT NULL ,
  `VALOR_MINIMO` FLOAT NULL ,
  `VALOR_MAXIMO` FLOAT NULL ,
  `ANALYSIS_PARAMETER_CODE` INT NOT NULL ,
  PRIMARY KEY (`CODE`) ,
  CONSTRAINT `fk_RANGO_ANALPARAM_ISO_ISO`
    FOREIGN KEY (`ISO_CODIGO` )
    REFERENCES `BARRELS`.`ISO` (`CODE` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION,
  CONSTRAINT `fk_RANGO_ANALPARAM_ISO_ANALPARAM`
    FOREIGN KEY (`ANALYSIS_PARAMETER_CODE` )
    REFERENCES `BARRELS`.`ANALYSIS_PARAMETER` (`CODE` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION)
;

CREATE  TABLE IF NOT EXISTS `BARRELS`.`RECEIPT` (
  `CODE` INT NOT NULL AUTO_INCREMENT,
  `NOTES` VARCHAR(45)  NULL ,
  `STATUS` VARCHAR(4)  NULL ,
  `CLIENT_CODE` INT NOT NULL ,
  `TOTAL_AMOUNT` FLOAT NOT NULL ,
  `SUBTOTAL` FLOAT NOT NULL ,
  `TAX_AMOUNT` FLOAT NOT NULL ,
  `DATE` DATE NOT NULL ,
  PRIMARY KEY (`CODE`) );
  
 CREATE  TABLE IF NOT EXISTS `BARRELS`.`RECEIPT_LINE` (
  `CODE` INT NOT NULL AUTO_INCREMENT,
  `CODE_RECEIPT` INT NOT NULL ,
  `DESCRIPTION` VARCHAR(45) NOT NULL ,
  `QUANTITY` FLOAT NOT NULL ,
  `AMOUNT` FLOAT NOT NULL ,
   PRIMARY KEY (`CODE`) ,
   CONSTRAINT `FK_CODE_RECEIPT_LINE` FOREIGN KEY (`CODE_RECEIPT`) REFERENCES `RECEIPT` (`CODE`))  ;

CREATE  TABLE IF NOT EXISTS `BARRELS`.`RECEIPT_LINE_EXIT` (
  `CODE` INT NOT NULL AUTO_INCREMENT,
  `CODE_EXIT` INT NOT NULL ,
   PRIMARY KEY (`CODE`) ,
   CONSTRAINT `FK_RECEIPT_LINE_EXIT` FOREIGN KEY (`CODE`) REFERENCES `RECEIPT_LINE` (`CODE`)  ,
   CONSTRAINT `FK_RECEIPT_LINE_EXIT_EXIT` FOREIGN KEY (`CODE_EXIT`) REFERENCES `EXIT` (`CODE`))  ;

CREATE  TABLE IF NOT EXISTS `BARRELS`.`RECEIPT_LINE_SAMPLE` (
  `CODE` INT NOT NULL AUTO_INCREMENT,
  `CODE_SAMPLE` INT NOT NULL ,
   PRIMARY KEY (`CODE`) ,
   CONSTRAINT `FK_RECEIPT_LINE_SAMPLE` FOREIGN KEY (`CODE`) REFERENCES `RECEIPT_LINE` (`CODE`)  ,
   CONSTRAINT `FK_RECEIPT_LINE_SAMPLE_SAMPLE` FOREIGN KEY (`CODE_SAMPLE`) REFERENCES `SAMPLE` (`CODE`))  ;

CREATE  TABLE IF NOT EXISTS `BARRELS`.`PAYMENT` (
  `CODE` INT NOT NULL AUTO_INCREMENT,
  `CLIENT_CODE` INT NOT NULL ,
  `RECEIPT_CODE` INT NULL ,
  `TYPE` VARCHAR(10) NOT NULL ,
  `AMOUNT` FLOAT NOT NULL ,
  `DATE` DATE NOT NULL ,
  `IDENTIFIER` VARCHAR(45) NULL ,
   PRIMARY KEY (`CODE`) ,
   CONSTRAINT `FK_PAYMENT_CLIENT` FOREIGN KEY (`CLIENT_CODE`) REFERENCES `CLIENT` (`CODE`)  ,
   CONSTRAINT `FK_PAYMENT_RECEIPT` FOREIGN KEY (`RECEIPT_CODE`) REFERENCES `RECEIPT` (`CODE`))  ;
   
 CREATE  TABLE IF NOT EXISTS `BARRELS`.`TAX` (
  `NAME` VARCHAR(13) NOT NULL ,
  `VALUE` FLOAT NOT NULL ,
   PRIMARY KEY (`NAME`) )